(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     20007,        673]*)
(*NotebookOutlinePosition[     50385,       1786]*)
(*  CellTagsIndexPosition[     50313,       1780]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Local (or relative) Extrema", "Subsection",
  CellTags->"5.1.1"],

Cell["DEFINITION", "DefinitionLabel",
  CellTags->"5.1.1"],

Cell[TextData[{
  "A function  f[x]  has a local (or relative) maximum at  x = c  if there is \
an interval  I  containing  c such that  f[",
  Cell[BoxData[
      \(c\)]],
  "] \[GreaterEqual] f[x]  for all other  x  in I."
}], "Definition",
  CellTags->"5.1.1"],

Cell["DEFINITION", "DefinitionLabel",
  CellTags->"5.1.1"],

Cell[TextData[{
  "A function  f[x]  has a local (or relative) minimum at  x = c  if there is \
an interval  I  containing  c such that  f[",
  Cell[BoxData[
      \(c\)]],
  "] \[LessEqual] f[x]  for all other  x  in I."
}], "Definition",
  CellTags->"5.1.1"],

Cell["\<\
For example, the next graph has a local minimum in blue and a local \
maximum in red, and neither of these are absolute extrema.\
\>", "Text",
  CellTags->"5.1.1"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Mathematica",
          FontSlant->"Italic"], " ", "example", " ", \(of : \ \ f[x_]\)}], 
      ":=", \(x\^3 - 3  x\)}]], "ExampleSection",
  FontFamily->"Times",
  CellTags->"5.1.1"],

Cell[TextData[{
  Cell[BoxData[
      ButtonBox["EVALUATE",
        ButtonData:>{},
        ButtonStyle->"InputButton"]]],
  StyleBox[" MATHEMATICA",
    FontSlant->"Italic"],
  " INPUT"
}], "InputLabel",
  CellTags->"5.1.1"],

Cell[BoxData[
    \(Clear[x, f]; f[x_] := x\^3 - 3\ x; \n
    curve = Plot[f[x], {x, \(-6\), 6}, PlotStyle \[Rule] DarkGreen, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] Identity]; \n
    Show[curve, Graphics[{Blue, PointSize[0.03], Point[{1, f[1]}]}], 
      Graphics[{Red, PointSize[0.03], Point[{\(-1\), f[\(-1\)]}]}], 
      DisplayFunction \[Rule] $DisplayFunction]; \)], "Input",
  CellTags->"5.1.1"]
}, Closed]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.309001 0.0368186 [
[.02381 .2965 -6 -9 ]
[.02381 .2965 6 0 ]
[.18254 .2965 -6 -9 ]
[.18254 .2965 6 0 ]
[.34127 .2965 -6 -9 ]
[.34127 .2965 6 0 ]
[.65873 .2965 -3 -9 ]
[.65873 .2965 3 0 ]
[.81746 .2965 -3 -9 ]
[.81746 .2965 3 0 ]
[.97619 .2965 -3 -9 ]
[.97619 .2965 3 0 ]
[1.025 .309 0 -6 ]
[1.025 .309 10 6 ]
[.4875 .03286 -24 -4.5 ]
[.4875 .03286 0 4.5 ]
[.4875 .12491 -12 -4.5 ]
[.4875 .12491 0 4.5 ]
[.4875 .21695 -24 -4.5 ]
[.4875 .21695 0 4.5 ]
[.4875 .40105 -18 -4.5 ]
[.4875 .40105 0 4.5 ]
[.4875 .49309 -6 -4.5 ]
[.4875 .49309 0 4.5 ]
[.4875 .58514 -18 -4.5 ]
[.4875 .58514 0 4.5 ]
[.5 .64303 -5 0 ]
[.5 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .309 m
.02381 .31525 L
s
[(-6)] .02381 .2965 0 1 Mshowa
.18254 .309 m
.18254 .31525 L
s
[(-4)] .18254 .2965 0 1 Mshowa
.34127 .309 m
.34127 .31525 L
s
[(-2)] .34127 .2965 0 1 Mshowa
.65873 .309 m
.65873 .31525 L
s
[(2)] .65873 .2965 0 1 Mshowa
.81746 .309 m
.81746 .31525 L
s
[(4)] .81746 .2965 0 1 Mshowa
.97619 .309 m
.97619 .31525 L
s
[(6)] .97619 .2965 0 1 Mshowa
.125 Mabswid
.06349 .309 m
.06349 .31275 L
s
.10317 .309 m
.10317 .31275 L
s
.14286 .309 m
.14286 .31275 L
s
.22222 .309 m
.22222 .31275 L
s
.2619 .309 m
.2619 .31275 L
s
.30159 .309 m
.30159 .31275 L
s
.38095 .309 m
.38095 .31275 L
s
.42063 .309 m
.42063 .31275 L
s
.46032 .309 m
.46032 .31275 L
s
.53968 .309 m
.53968 .31275 L
s
.57937 .309 m
.57937 .31275 L
s
.61905 .309 m
.61905 .31275 L
s
.69841 .309 m
.69841 .31275 L
s
.7381 .309 m
.7381 .31275 L
s
.77778 .309 m
.77778 .31275 L
s
.85714 .309 m
.85714 .31275 L
s
.89683 .309 m
.89683 .31275 L
s
.93651 .309 m
.93651 .31275 L
s
.25 Mabswid
0 .309 m
1 .309 L
s
gsave
1.025 .309 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 .03286 m
.50625 .03286 L
s
[(-7.5)] .4875 .03286 1 0 Mshowa
.5 .12491 m
.50625 .12491 L
s
[(-5)] .4875 .12491 1 0 Mshowa
.5 .21695 m
.50625 .21695 L
s
[(-2.5)] .4875 .21695 1 0 Mshowa
.5 .40105 m
.50625 .40105 L
s
[(2.5)] .4875 .40105 1 0 Mshowa
.5 .49309 m
.50625 .49309 L
s
[(5)] .4875 .49309 1 0 Mshowa
.5 .58514 m
.50625 .58514 L
s
[(7.5)] .4875 .58514 1 0 Mshowa
.125 Mabswid
.5 .05127 m
.50375 .05127 L
s
.5 .06968 m
.50375 .06968 L
s
.5 .08809 m
.50375 .08809 L
s
.5 .1065 m
.50375 .1065 L
s
.5 .14332 m
.50375 .14332 L
s
.5 .16173 m
.50375 .16173 L
s
.5 .18014 m
.50375 .18014 L
s
.5 .19854 m
.50375 .19854 L
s
.5 .23536 m
.50375 .23536 L
s
.5 .25377 m
.50375 .25377 L
s
.5 .27218 m
.50375 .27218 L
s
.5 .29059 m
.50375 .29059 L
s
.5 .32741 m
.50375 .32741 L
s
.5 .34582 m
.50375 .34582 L
s
.5 .36423 m
.50375 .36423 L
s
.5 .38264 m
.50375 .38264 L
s
.5 .41946 m
.50375 .41946 L
s
.5 .43787 m
.50375 .43787 L
s
.5 .45628 m
.50375 .45628 L
s
.5 .47468 m
.50375 .47468 L
s
.5 .5115 m
.50375 .5115 L
s
.5 .52991 m
.50375 .52991 L
s
.5 .54832 m
.50375 .54832 L
s
.5 .56673 m
.50375 .56673 L
s
.5 .01445 m
.50375 .01445 L
s
.5 .60355 m
.50375 .60355 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 .392 0 r
.5 Mabswid
.30053 0 m
.30316 .0212 L
.32313 .14764 L
.34157 .23661 L
.36029 .30261 L
.37094 .3303 L
.38092 .35037 L
.38588 .35837 L
.3913 .36569 L
.39608 .37097 L
.40117 .37545 L
.40376 .37729 L
.40621 .37877 L
.40858 .37996 L
.41077 .38086 L
.41286 .38154 L
.41506 .38208 L
.4162 .38229 L
.41727 .38244 L
.41844 .38255 L
.41969 .38262 L
.42091 .38264 L
.4216 .38262 L
.42225 .38259 L
.42356 .38249 L
.4243 .38241 L
.42498 .38231 L
.42736 .38187 L
.42987 .3812 L
.4326 .38025 L
.43515 .37917 L
.44093 .37603 L
.45066 .36882 L
.46105 .35885 L
.50255 .30545 L
.52335 .27744 L
.53249 .26631 L
.54253 .25547 L
.55154 .24735 L
.56122 .2407 L
.56396 .23926 L
.56656 .23809 L
.56909 .23714 L
.57144 .23643 L
.57365 .23592 L
.57489 .23571 L
.57601 .23556 L
.57725 .23544 L
.57794 .2354 L
.57858 .23537 L
Mistroke
.57976 .23537 L
.581 .23541 L
.58222 .23551 L
.58292 .23559 L
.58355 .23568 L
.58471 .23587 L
.58597 .23615 L
.58817 .23677 L
.5905 .23764 L
.59575 .2404 L
.60068 .24404 L
.60951 .25332 L
.61448 .26017 L
.61902 .26754 L
.63798 .31046 L
.64872 .34429 L
.6587 .38251 L
.6792 .48341 L
.6978 .60367 L
Mfstroke
.6978 .60367 m
.69955 .61803 L
s
0 0 1 r
.03 w
.57937 .23536 Mdot
1 0 0 r
.42063 .38264 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00OE7oi00<1P7oiOoT0
<7oi00<007oiOoT0UWoi001DOoT00`60OoUon@0`OoT00`00OoUon@2FOoT005Aon@030H1onGoi031o
n@03001onGoi09Ion@00E7oi00<1P7oiOoT0<7oi0P00Ugoi001DOoT00`60OoUon@0`OoT00`00OoUo
n@2FOoT005Aon@030H1onGoi031on@03001onGoi09Ion@00E7oi00<1P7oiOoT07Goi00<007oiOoT0
0goi0P000goi0`001Goi00<007oiOoT0UWoi001DOoT00`60OoUon@0MOoT00`00OoUon@03OoT20006
OoT00`00OoUon@02OoT00`00OoUon@2FOoT005Aon@030H1onGoi01Ion@D000=on@03001onGoi00Yo
n@03001onGoi009on@8009Mon@00EGoi00<1P7oiOoT07Goi00<007oiOoT01goi0`001Goi00<007oi
OoT0UWoi001EOoT00`60OoUon@0NOoT00`00OoUon@06OoT00`00OoUon@05OoT00`00OoUon@2FOoT0
05Eon@030H1onGoi01]on@@000Qon@@000Aon@03001onGoi09Ion@00EGoi00<1P7oiOoT0;goi00<0
07oiOoT0UWoi001EOoT00`60OoUon@0_OoT2002GOoT005Eon@030H1onGoi02mon@03001onGoi09Io
n@00EGoi00<1P7oiOoT0;goi00<007oiOoT0UWoi001FOoT00`60OoUon@0^OoT00`00OoUon@2FOoT0
05Ion@030H1onGoi02ion@8009Mon@00EWoi00<1P7oiOoT0;Woi00<007oiOoT0UWoi001FOoT00`60
OoUon@0^OoT00`00OoUon@2FOoT005Ion@030H1onGoi02ion@03001onGoi09Ion@00EWoi00<1P7oi
OoT0;Woi00<007oiOoT0UWoi001GOoT00`60OoUon@0]OoT2002GOoT005Mon@030H1onGoi02eon@03
001onGoi09Ion@00Egoi00<1P7oiOoT0;Goi00<007oiOoT0UWoi001GOoT00`60OoUon@0]OoT00`00
OoUon@2FOoT005Mon@030H1onGoi02eon@03001onGoi09Ion@00Egoi00<1P7oiOoT0;Goi0P00Ugoi
001HOoT00`60OoUon@0/OoT00`00OoUon@2FOoT005Qon@030H1onGoi02aon@03001onGoi09Ion@00
F7oi00<1P7oiOoT097oi0`001Goi00<007oiOoT0UWoi001HOoT00`60OoUon@0WOoT00`00OoUon@02
OoT00`00OoUon@2FOoT005Qon@030H1onGoi01ion@D000Aon@03001onGoi009on@8009Mon@00F7oi
00<1P7oiOoT097oi0`001Goi00<007oiOoT0UWoi001HOoT00`60OoUon@0TOoT00`00OoUon@05OoT0
0`00OoUon@2FOoT005Uon@030H1onGoi02=on@@000Aon@03001onGoi09Ion@00FGoi00<1P7oiOoT0
:goi0P00Ugoi001IOoT00`60OoUon@0[OoT00`00OoUon@2FOoT005Uon@030H1onGoi02]on@03001o
nGoi09Ion@00FGoi00<1P7oiOoT0:goi00<007oiOoT0UWoi001JOoT00`60OoUon@0ZOoT00`00OoUo
n@2FOoT005Yon@030H1onGoi02Yon@8009Mon@00FWoi00<1P7oiOoT0:Woi00<007oiOoT0UWoi001J
OoT00`60OoUon@0ZOoT00`00OoUon@2FOoT005Yon@030H1onGoi02Yon@03001onGoi09Ion@00Fgoi
00<1P7oiOoT0:Goi00<007oiOoT0UWoi001KOoT00`60OoUon@0YOoT2002GOoT005]on@030H1onGoi
02Uon@03001onGoi09Ion@00Fgoi00<1P7oiOoT0:Goi00<007oiOoT0UWoi001LOoT00`60OoUon@0X
OoT00`00OoUon@2FOoT005aon@030H1onGoi02Qon@8009Mon@00G7oi00<1P7oiOoT0:7oi00<007oi
OoT0UWoi001LOoT00`60OoUon@0XOoT00`00OoUon@2FOoT005aon@030H1onGoi01Aon@@000=on@80
00=on@<000Eon@03001onGoi09Ion@00GGoi00<1P7oiOoT057oi00<007oiOoT00goi0P001Woi00<0
07oiOoT00Woi00<007oiOoT0UWoi001MOoT00`60OoUon@0=OoT50003OoT00`00OoUon@0:OoT00`00
OoUon@02OoT2002GOoT005eon@030H1onGoi01Ion@03001onGoi00Ion@<000Eon@03001onGoi09Io
n@00GGoi00<1P7oiOoT04goi00@007oiOoT000Qon@03001onGoi00Eon@03001onGoi011on@<07h=o
n@00GGoi00<1P7oiOoT057oi0P002Goi100017oi00<007oiOoT03goi1@0OPWoi001NOoT00`60OoUo
n@0VOoT00`00OoUon@0>OoT701n1OoT005ion@030H1onGoi02Ion@8000mon@L07h5on@00GWoi00<1
P7oiOoT09Woi00<007oiOoT037oi0P601`0O0P60Ogoi001NOoT00`60OoUon@0VOoT00`00OoUon@0;
OoT01060OoUonGoi1@0O0goi00<1P7oiOoT0O7oi001OOoT00`60OoUon@0UOoT00`00OoUon@0:OoT0
0`60OoUon@03OoT301l4OoT00`60OoUon@1lOoT005mon@030H1onGoi02Eon@03001onGoi00Uon@03
0H1onGoi00aon@030H1onGoi07]on@00Ggoi00<1P7oiOoT09Goi0P002Goi00<1P7oiOoT03Woi00<1
P7oiOoT0NWoi001POoT00`60OoUon@0TOoT00`00OoUon@07OoT00`60OoUon@0@OoT00`60OoUon@1i
OoT0061on@030H1onGoi02Aon@03001onGoi00Ion@030H1onGoi015on@030H1onGoi07Uon@00H7oi
00<1P7oiOoT097oi00<007oiOoT01Goi00<1P7oiOoT04goi00<1P7oiOoT0N7oi000?OoT2000VOoT3
000UOoT200000`60001on@0SOoT20006OoT00`60OoUon@0COoT00`60OoUon@06OoT4000UOoT3000V
OoT2000NOoT000ion@04001onGoi000VOoT00`00OoUon@0UOoT00`000H1on@0TOoT00`00OoUon@04
OoT00`60OoUon@0EOoT00`60OoUon@06OoT00`00OoUon@0VOoT00`00OoUon@0TOoT01000OoUon@00
7Goi0008OoT500001Goi001onGoi00007Woi1@0000=on@0000000P007goi1@000goi00<1P7oiOoT0
8goi00<007oiOoT00goi00<1P7oiOoT05Woi00<1P7oiOoT01goi00<007oiOoT08goi10009Goi00@0
07oiOoT001eon@003Woi0`009Goi00<007oi0000:7oi00<1P000OoT08goi00<007oiOoT00goi00<1
P7oiOoT05goi00<1P7oiOoT01goi00<007oiOoT08Woi00<007oi00009Woi0`007Woi000>OoT00`00
OoUon@0UOoT00`00OoT0000VOoT01000OoUon@6097oi00<007oiOoT00Woi00<1P7oiOoT067oi00<1
P7oiOoT017oi00@007oiOoT002Aon@03001on@0002Ion@03001onGoi01ion@003goi0`009Goi0P00
9goi0P0000<1P7oiOoT08Woi0P000Woi00<1P7oiOoT06Woi00<1P7oiOoT017oi0P009Woi0P009goi
0`007Goi001ROoT00`60OoUon@0ROoT01000OoUon@607Goi00<1P7oiOoT0MGoi001SOoT00`60OoUo
n@0QOoT00`00OoT1P00NOoT00`60OoUon@1eOoT006=on@030H1onGoi025on@030001P7oi01mon@03
0H1onGoi06=on@800003OoT0000000aon@00Hgoi00<1P7oiOoT08Goi00<1P7oiOoT07goi00<1P7oi
OoT0I7oi00<007oi00003Goi0007OoUM00000`600000000P00000`600000000P00000`600000001K
0009OoT00`00OoUon@0<OoT000eon@03001onGoi00Mon@03001onGoi00Mon@03001onGoi00Mon@03
001onGoi00Mon@03001onGoi00Qon@03001onGoi00Mon@03001onGoi00Mon@03001onGoi00Mon@03
001onGoi00=on@050H1onGoiOoT00009OoT00`00OoUon@08OoT00`00OoUon@06OoT00`60001on@08
OoT00`00OoUon@07OoT00`00OoUon@07OoT00`00OoUon@02OoT00`60OoUon@03OoT00`00OoUon@07
OoT00`00OoUon@07OoT00`00OoUon@07OoT00`00OoUon@07OoT00`00OoUon@07OoT00`00OoUon@08
OoT00`00OoUon@07OoT00`00OoUon@07OoT00`00OoUon@0<OoT00`00OoT0000=OoT006Eon@030H1o
nGoi01eon@030H1on@0002=on@030H1onGoi065on@800003OoT0000000aon@00IGoi00<1P7oiOoT0
77oi00@1P7oiOoT002=on@030H1onGoi079on@00IGoi00<1P7oiOoT077oi00@1P7oiOoT002=on@03
0H1onGoi079on@00IWoi00<1P7oiOoT06Woi00@1P7oiOoUon@8002=on@030H1onGoi075on@00IWoi
00<1P7oiOoT06Goi00<1P7oiOoT00Woi00<007oiOoT08Woi00<1P7oiOoT0LGoi001WOoT00`60OoUo
n@0HOoT00`60OoUon@02OoT00`00OoUon@0ROoT00`60OoUon@1aOoT006Mon@030H1onGoi01Mon@03
0H1onGoi00=on@03001onGoi02=on@030H1onGoi071on@00Igoi00<1P7oiOoT05Woi00<1P7oiOoT0
17oi0P0097oi00<1P7oiOoT0L7oi001XOoT00`60OoUon@0DOoT00`60OoUon@05OoT00`00OoUon@0S
OoT00`60OoUon@1`OoT006Uon@030H1onGoi01=on@030H1onGoi00Eon@03001onGoi02=on@030H1o
nGoi071on@00JWoi00<1P7oiOoT04Goi00<1P7oiOoT01Woi00<007oiOoT097oi00<1P7oiOoT0Kgoi
001ZOoT00`60OoUon@0?OoT20H09OoT00`00OoUon@0TOoT00`60OoUon@1_OoT006]on@030H1onGoi
00eon@030H1onGoi00Uon@8002Eon@030H1onGoi06mon@00Jgoi00<1P7oiOoT037oi00<1P7oiOoT0
2Woi00<007oiOoT09Goi00<1P7oiOoT0KWoi001/OoT00`60OoUon@02OoT3O005OoT00`60OoUon@0;
OoT00`00OoUon@0UOoT00`60OoUon@1^OoT006eon@81P003OoUl07`000=l009on@81P0ion@03001o
nGoi02Eon@030H1onGoi06ion@00Kgoi1g`000<1P7oiOoT03Woi00<007oiOoT09Woi00<1P7oiOoT0
KGoi001_OoT7O00AOoT2000WOoT00`60OoUon@1]OoT006mon@Ml015on@03001onGoi02Ion@030H1o
nGoi06eon@00L7oi1G`00P000goi0P000goi0`001Goi00<007oiOoT09Woi00<1P7oiOoT0KGoi001a
OoT3O0000`00OoUon@03OoT20006OoT00`00OoUon@02OoT00`00OoUon@0VOoT00`60OoUon@1]OoT0
07Eon@03001onGoi00Yon@03001onGoi009on@8002Qon@030H1onGoi06aon@00MWoi00<007oiOoT0
1Woi0`001Goi00<007oiOoT09goi00<1P7oiOoT0K7oi001cOoT01000OoUon@0027oi00<007oiOoT0
1Goi00<007oiOoT09goi00<1P7oiOoT0K7oi001dOoT20009OoT40004OoT00`00OoUon@0WOoT00`60
OoUon@1/OoT008Mon@03001onGoi02Mon@030H1onGoi06aon@00Qgoi0P00:Goi00<1P7oiOoT0Jgoi
0027OoT00`00OoUon@0XOoT00`60OoUon@1[OoT008Mon@03001onGoi02Qon@030H1onGoi06]on@00
Qgoi00<007oiOoT0:7oi00<1P7oiOoT0Jgoi0027OoT00`00OoUon@0XOoT00`60OoUon@1[OoT008Mo
n@8002Yon@030H1onGoi06Yon@00Qgoi00<007oiOoT0:Goi00<1P7oiOoT0JWoi0027OoT00`00OoUo
n@0YOoT00`60OoUon@1ZOoT008Mon@03001onGoi02Uon@030H1onGoi06Yon@00Qgoi00<007oiOoT0
:Goi00<1P7oiOoT0JWoi0027OoT2000[OoT00`60OoUon@1YOoT008Mon@03001onGoi02Yon@030H1o
nGoi06Uon@00Qgoi00<007oiOoT0:Woi00<1P7oiOoT0JGoi0027OoT00`00OoUon@0ZOoT00`60OoUo
n@1YOoT008Mon@8002]on@030H1onGoi06Uon@00Qgoi00<007oiOoT0:goi00<1P7oiOoT0J7oi0027
OoT00`00OoUon@0[OoT00`60OoUon@1XOoT007mon@<000Eon@03001onGoi02]on@030H1onGoi06Qo
n@00PWoi00<007oiOoT00Woi00<007oiOoT0:goi00<1P7oiOoT0J7oi0022OoT00`00OoUon@02OoT2
000/OoT00`60OoUon@1XOoT007mon@<000Eon@03001onGoi02]on@030H1onGoi06Qon@00Ogoi00<0
07oiOoT01Goi00<007oiOoT0;7oi00<1P7oiOoT0Igoi001oOoT40004OoT00`00OoUon@0/OoT00`60
OoUon@1WOoT008Mon@03001onGoi02aon@030H1onGoi06Mon@00Qgoi0P00;Goi00<1P7oiOoT0Igoi
0027OoT00`00OoUon@0/OoT00`60OoUon@1WOoT008Mon@03001onGoi02aon@030H1onGoi06Mon@00
Qgoi00<007oiOoT0;Goi00<1P7oiOoT0IWoi0027OoT2000^OoT00`60OoUon@1VOoT008Mon@03001o
nGoi02eon@030H1onGoi06Ion@00Qgoi00<007oiOoT0;Goi00<1P7oiOoT0IWoi0027OoT00`00OoUo
n@0]OoT00`60OoUon@1VOoT008Mon@03001onGoi02eon@030H1onGoi06Ion@00Qgoi0P00;goi00<1
P7oiOoT0IGoi0027OoT00`00OoUon@0^OoT00`60OoUon@1UOoT008Mon@03001onGoi02ion@030H1o
nGoi06Eon@00Qgoi00<007oiOoT0;Woi00<1P7oiOoT0IGoi0027OoT00`00OoUon@0^OoT00`60OoUo
n@1UOoT008Mon@8002mon@030H1onGoi06Eon@00Qgoi00<007oiOoT0;goi00<1P7oiOoT0I7oi0027
OoT00`00OoUon@0_OoT00`60OoUon@1TOoT007Aon@03001onGoi00=on@8000=on@<000Eon@03001o
nGoi02mon@030H1onGoi06Aon@00M7oi00<007oiOoT00goi0P001Woi00<007oiOoT00Woi00<007oi
OoT0;goi00<1P7oiOoT0I7oi001eOoT00`00OoUon@0:OoT00`00OoUon@02OoT2000`OoT00`60OoUo
n@1TOoT007Eon@03001onGoi00Mon@<000Eon@03001onGoi02mon@030H1onGoi06Aon@00MWoi00<0
07oiOoT01Woi00<007oiOoT01Goi00<007oiOoT0<7oi00<1P7oiOoT0Hgoi001cOoT40008OoT40004
OoT00`00OoUon@0`OoT00`60OoUon@1SOoT008Mon@80035on@030H1onGoi06=on@00Qgoi00<007oi
OoT0<7oi00<1P7oiOoT0Hgoi0027OoT00`00OoUon@0`OoT00`60OoUon@1SOoT008Mon@03001onGoi
031on@030H1onGoi06=on@00Qgoi00<007oiOoT0<7oi00<1P7oiOoT0Hgoi003oOoTQOoT00?monB5o
n@00ogoi8Goi003oOoTQOoT00?monB5on@00ogoi8Goi003oOoTQOoT008Aon@<009Uon@00QGoi00<0
07oiOoT0V7oi0026OoT00`00OoUon@2GOoT008Ion@03001onGoi09Mon@00QGoi00<007oi0000V7oi
0025OoT00`00OoT0002HOoT008Aon@800003OoT0000009Mon@00ogoi8Goi003oOoTQOoT00?monB5o
n@00ogoi8Goi0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.64606, -8.39261, 
  0.0491232, 0.105889}}]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{523, 542},
WindowMargins->{{35, Automatic}, {Automatic, 4}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\

Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ScriptSizeMultipliers->1,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "CellBrackets"],
    PageWidth->WindowWidth,
    ScriptSizeMultipliers->1,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptSizeMultipliers->0.71,
    ScriptMinSize->7,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\

The options defined for the style below will be used at the 
Notebook level.
\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            TextData[ {"Printed by ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], " from ", 
              StyleBox[ "The Calculus Wiz", FontSlant -> "Italic"], 
              " by K.D.Stroyan. \n\[Copyright] 1996. All rights reserved."}], 
            "Footer"], None}, {None, Cell[ 
            TextData[ {"Printed by ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], " from ", 
              StyleBox[ "The Calculus Wiz", FontSlant -> "Italic"], 
              " by K.D.Stroyan. \n\[Copyright] 1996. All rights reserved."}], 
            "Footer"], None}},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FirstPageFace"->Right},
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 0}, {6, 6}},
    LineSpacing->{1, 3},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[1],
    Background->GrayLevel[0.500008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 0}, {6, 6}},
    LineSpacing->{1, 3},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.4, 0, 0.4]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[1],
    Background->GrayLevel[0.500008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 0}, {10, 8}},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 0.2, 0]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{26, Inherited}, {4, 20}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {4, 20}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{12, Inherited}, {8, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->1},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->15,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {4, 8}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    LimitsPositioningTokens->{},
    FontFamily->"Times",
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {4, 4}},
    ParagraphSpacing->{0, 6},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    LimitsPositioningTokens->{},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\

The cells in this section define styles used for input and output 
to the kernel.  Be careful when modifying, renaming, or removing these 
styles, because the front end associates special meanings with these style 
names.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{52, 26}, {0, 0}},
    Evaluatable->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{37, 0}, {6, 6}},
    FontSize->10,
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{52, 26}, {8, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->{"SectionGrouping", 60},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{37, 0}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{52, 26}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{52, 26}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 60},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{52, 26}, {8, 0}},
    CellGroupingRules->{"SectionGrouping", 60},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{28, Inherited}, {Inherited, 0}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Miscellaneous Elements", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 10}},
    StyleMenuListing->None,
    FontSize->16,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{50, 10}, {5, 5}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    LimitsPositioningTokens->{},
    FontFamily->"Times",
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{0, 0}, {4, 4}},
    TextAlignment->Center,
    ParagraphSpacing->{0, 6},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{50, 10}, {5, 5}},
    CellGroupingRules->{"SectionGrouping", 60},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FormatType->StandardForm,
    LimitsPositioningTokens->{},
    FontFamily->"Times",
    FontSize->14,
    FontColor->RGBColor[0.4, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{0, 0}, {4, 4}},
    TextAlignment->Center,
    ParagraphSpacing->{0, 6},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TheoremLabel"],
    CellMargins->{{12, 26}, {0, 8}},
    CellBracketOptions->{"Color"->GrayLevel[1]},
    PageBreakBelow->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{Inherited, Inherited}, {4, 5}},
    LineSpacing->{1, 1},
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.239994, 0, 0.4]],
  
  Cell[StyleData["TheoremLabel", "Printout"],
    CellMargins->{{2, 0}, {0, 6}},
    Background->GrayLevel[0.2]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellMargins->{{12, 26}, {8, 0}},
    CellBracketOptions->{"Color"->GrayLevel[1]},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    LimitsPositioningTokens->{},
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Printout"],
    CellFrame->{{1, 1}, {1, 0}},
    CellMargins->{{2, 0}, {2, 0}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionLabel"],
    CellMargins->{{12, 26}, {0, 8}},
    CellBracketOptions->{"Color"->GrayLevel[1]},
    PageBreakBelow->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{Inherited, Inherited}, {4, 5}},
    LineSpacing->{1, 1},
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.100008, 0.360006, 0.459998]],
  
  Cell[StyleData["DefinitionLabel", "Printout"],
    CellMargins->{{2, 0}, {2, 6}},
    Background->GrayLevel[0.2]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellMargins->{{12, 26}, {8, 0}},
    CellBracketOptions->{"Color"->GrayLevel[1]},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->False,
    ShowStringCharacters->True,
    LimitsPositioningTokens->{},
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.659998, 0.659998]],
  
  Cell[StyleData["Definition", "Printout"],
    CellFrame->{{1, 1}, {1, 0}},
    CellMargins->{{2, 0}, {2, 0}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Information"],
    CellMargins->{{12, 26}, {8, 8}},
    CellBracketOptions->{"Color"->GrayLevel[1]},
    PageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    LimitsPositioningTokens->{},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.2, 0]],
  
  Cell[StyleData["Information", "Printout"],
    CellMargins->{{37, 0}, {2, 6}},
    Background->GrayLevel[0.500008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputLabel"],
    CellMargins->{{52, 26}, {0, 8}},
    PageBreakBelow->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{Inherited, Inherited}, {2, 3}},
    LineSpacing->{1, 1},
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.6, 0.4, 0]],
  
  Cell[StyleData["InputLabel", "Printout"],
    CellMargins->{{2, 0}, {2, 6}},
    Background->GrayLevel[0.2]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseBig"],
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 0}, {10, 8}},
    ParagraphIndent->-84,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 0.6, 0]],
  
  Cell[StyleData["ExerciseBig", "Printout"],
    CellMargins->{{2, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{23, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    LimitsPositioningTokens->{},
    CounterIncrements->"Exercise",
    CounterAssignments->{{"NumberedExercise", 0}},
    FontFamily->"Times",
    FontSize->15,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Printout"],
    CellDingbat->None,
    CellMargins->{{2, Inherited}, {4, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseLabel"],
    CellMargins->{{10, 10}, {0, 8}},
    PageBreakBelow->False,
    GroupPageBreakWithin->False,
    LineSpacing->{1, 1},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    GridBoxOptions->{ColumnWidths->2,
    RowMinHeight->1.6}],
  
  Cell[StyleData["ExerciseLabel", "Printout"],
    CellMargins->{{2, 0}, {2, 6}},
    Background->GrayLevel[0.2]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    Evaluatable->False,
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {2, 10}},
    LineSpacing->{1, 0},
    FontSize->22,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0, 0.4]],
  
  Cell[StyleData["DialogHeader", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->18,
    Background->GrayLevel[0.300008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogTitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    Evaluatable->False,
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {2, 1}},
    LineSpacing->{1, 3},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.4, 0, 0.4]],
  
  Cell[StyleData["DialogTitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->12,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogButtonBar"],
    CellMargins->{{8, 0}, {8, 4}},
    Evaluatable->False],
  
  Cell[StyleData["DialogButtonBar", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogText"],
    ShowCellBracket->False,
    CellMargins->{{8, 4}, {0, 2}},
    Evaluatable->False,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["DialogText", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogEntryField"],
    CellFrame->{{1, 0}, {1, 1}},
    ShowCellBracket->False,
    CellMargins->{{41, 0}, {6, 1}},
    Evaluatable->False,
    CellFrameMargins->{{8, 8}, {4, 4}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold",
    Background->GrayLevel[1]],
  
  Cell[StyleData["DialogEntryField", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogTextEntryField"],
    CellFrame->{{1, 0}, {1, 1}},
    ShowCellBracket->False,
    CellMargins->{{41, 0}, {6, 1}},
    Evaluatable->False,
    CellFrameMargins->{{8, 8}, {4, 4}},
    Background->GrayLevel[1]],
  
  Cell[StyleData["DialogTextEntryField", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogDoButton"],
    CellFrame->{{1, 0}, {0, 1}},
    ShowCellBracket->False,
    CellMargins->{{41, 0}, {4, 8}},
    Evaluatable->False,
    CellFrameColor->RGBColor[1, 0.4, 0]],
  
  Cell[StyleData["DialogDoButton", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogCodeCell"],
    ShowCellBracket->False,
    CellMargins->{{6, 0}, {4, 4}},
    Evaluatable->False,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogCodeCell", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\

The following styles are useful for numbered equations, figures, 
etc.  They automatically give the cell a FrameLabel containing a reference to \

a particular counter, and also increment that counter.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{60, 10}, {5, 5}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    LimitsPositioningTokens->{},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    TextAlignment->Center,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\

The cells below define styles useful for making hypertext 
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, 
or between Notebooks.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenGroup"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionMove[ 
          FrontEnd`SelectedNotebook[ ], All, ButtonCell], 
        FrontEndToken[ "SelectionOpenAllGroups"]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["OpenGroup", "Printout"],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoButton"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonEvaluator->Automatic,
    Background->RGBColor[1, 0.4, 0],
    ButtonNote->"Do It!"}],
  
  Cell[StyleData["DoButton", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UtilityButton"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 1, 0.8],
    ButtonBoxOptions->{ButtonMinHeight->1.3,
    Background->RGBColor[0.8, 0.6, 0.4],
    ButtonNote->None}],
  
  Cell[StyleData["UtilityButton", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SolverButton"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonMinHeight->1.2,
    Background->RGBColor[0.6, 0, 0],
    ButtonNote->None}],
  
  Cell[StyleData["SolverButton", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PaletteButton"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ ]], "Palettes"}, "CalculusWiz.nb"], None},
    ButtonMinHeight->1.23,
    Background->RGBColor[1, 0.4, 0],
    ButtonNote->None}],
  
  Cell[StyleData["PaletteButton", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TemplateButton"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonMinHeight->1.3,
    Background->RGBColor[1, 0.6, 0],
    ButtonNote->None}],
  
  Cell[StyleData["TemplateButton", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputButton"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
        FrontEnd`SelectionMove[ 
          ButtonNotebook[ ], All, ButtonCell], 
        FrontEnd`SelectionMove[ 
          ButtonNotebook[ ], Next, Cell], 
        FrontEnd`SelectionEvaluate[ 
          ButtonNotebook[ ]]}],
    Active->True,
    ButtonMinHeight->1.3,
    Background->RGBColor[0.6, 0, 0],
    ButtonNote->None}],
  
  Cell[StyleData["InputButton", "Printout"]]
  }, Closed]],
  
  Cell["\<\

The following styles are for linking automatically to the on-line help \
system.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[1],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[1],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[1],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[1],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherResourcesLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherResources", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherResourcesLink", "Printout"],
    FontColor->GrayLevel[1],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "5.1.1"->{
    Cell[1731, 51, 70, 1, 41, "Subsection",
      CellTags->"5.1.1"],
    Cell[1804, 54, 58, 1, 30, "DefinitionLabel",
      CellTags->"5.1.1"],
    Cell[1865, 57, 263, 7, 56, "Definition",
      CellTags->"5.1.1"],
    Cell[2131, 66, 58, 1, 30, "DefinitionLabel",
      CellTags->"5.1.1"],
    Cell[2192, 69, 260, 7, 56, "Definition",
      CellTags->"5.1.1"],
    Cell[2455, 78, 173, 4, 52, "Text",
      CellTags->"5.1.1"],
    Cell[2653, 86, 243, 7, 32, "ExampleSection",
      CellTags->"5.1.1"],
    Cell[2899, 95, 225, 9, 32, "InputLabel",
      CellTags->"5.1.1"],
    Cell[3127, 106, 442, 8, 132, "Input",
      CellTags->"5.1.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"5.1.1", 49646, 1757}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 70, 1, 41, "Subsection",
  CellTags->"5.1.1"],
Cell[1804, 54, 58, 1, 30, "DefinitionLabel",
  CellTags->"5.1.1"],
Cell[1865, 57, 263, 7, 56, "Definition",
  CellTags->"5.1.1"],
Cell[2131, 66, 58, 1, 30, "DefinitionLabel",
  CellTags->"5.1.1"],
Cell[2192, 69, 260, 7, 56, "Definition",
  CellTags->"5.1.1"],
Cell[2455, 78, 173, 4, 52, "Text",
  CellTags->"5.1.1"],

Cell[CellGroupData[{
Cell[2653, 86, 243, 7, 32, "ExampleSection",
  CellTags->"5.1.1"],
Cell[2899, 95, 225, 9, 32, "InputLabel",
  CellTags->"5.1.1"],
Cell[3127, 106, 442, 8, 132, "Input",
  CellTags->"5.1.1"]
}, Closed]],
Cell[3584, 117, 16407, 553, 206, 6996, 432, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

