(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     44245,       1815]*)
(*NotebookOutlinePosition[     45085,       1842]*)
(*  CellTagsIndexPosition[     45041,       1838]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PrintingStyleEnvironment->"Printout",
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"PrintingMargins"->{{97, 97}, {180, 64}},
  "FirstPageHeader"->False,
  "FacingPages"->True},
  CellLabelAutoDelete->False,
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ShowCellBracket->False,
  ScriptMinSize->9],

Cell[StyleData[All, "AllBrackets"],
  PageWidth->WindowWidth,
  ShowCellBracket->True,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  ScriptMinSize->5,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "EnhancedPrintout"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  ScriptMinSize->5,
  FontFamily->"Palatino",
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakAbove->True,
  PageBreakBelow->False,
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontSize->30],

Cell[StyleData["Title", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontFamily->"Futura",
  FontSize->30]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {10, 2}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->28],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontSize->24],

Cell[StyleData["Subtitle", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontFamily->"Futura",
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->12],

Cell[StyleData["Subsubtitle", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontFamily->"Futura",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{0, 0}, {0.5, 0}},
  CellMargins->{{10, Inherited}, {8, 30}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->8,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->20,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{2, 0}, {7, 24}},
  FontSize->16],

Cell[StyleData["Section", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{24, Inherited}, {8, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 24}},
  FontSize->12],

Cell[StyleData["Subsection", "EnhancedPrintout"],
  CellMargins->{{9, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellMargins->{{12, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Helvetica",
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{2, 0}, {7, 18}},
  FontSize->10],

Cell[StyleData["Subsubsection", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {7, 18}},
  FontFamily->"Futura",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontSize->11],

Cell[StyleData["Text", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"SmallText",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontSize->7],

Cell[StyleData["SmallText", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  ShowCellBracket->True,
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["Input", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9],

Cell[StyleData["Input", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  ShowCellBracket->True,
  CellMargins->{{46, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9],

Cell[StyleData["Output", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  ShowCellBracket->True,
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Message", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->9,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  ShowCellBracket->True,
  CellMargins->{{75, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontSize->9],

Cell[StyleData["Print", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  ShowCellBracket->True,
  CellMargins->{{47, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9],

Cell[StyleData["Graphics", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontFamily->"Courier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "EnhancedPrintout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[StyleData["SO10"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "Printout"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "EnhancedPrintout"],
  StyleMenuListing->None,
  FontFamily->"Futura",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["MathCaption"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{46, 42}, {0, 14}},
  PageBreakBelow->False,
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8},
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["MathCaption", "Printout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["MathCaption", "EnhancedPrintout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Commentary"],
  CellFrame->{{2, 0}, {0, 0}},
  CellMargins->{{36, 10}, {7, 7}},
  PageBreakBelow->False,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0, 0.2, 1],
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  FontSlant->"Italic"],

Cell[StyleData["Commentary", "Printout"],
  CellMargins->{{36, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontSize->10],

Cell[StyleData["Commentary", "EnhancedPrintout"],
  CellMargins->{{36, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText"],
  CellMargins->{{20, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-21,
  CounterIncrements->"ItemizedText"],

Cell[StyleData["ItemizedText", "Printout"],
  ParagraphIndent->-18,
  FontSize->11],

Cell[StyleData["ItemizedText", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedTextNote"],
  CellMargins->{{41, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  CounterIncrements->"Text"],

Cell[StyleData["ItemizedTextNote", "Printout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontSize->11],

Cell[StyleData["ItemizedTextNote", "EnhancedPrintout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{20, 4}, {0, 6}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Text"],

Cell[StyleData["IndentedText", "Printout"],
  FontSize->11],

Cell[StyleData["IndentedText", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Emphasis Boxes and Pictures", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.3, 0.7},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox3Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.2, 0.3, 0.5},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox3Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["DefinitionBox3Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox4Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.15, 0.35, 0.15, 0.35},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox4Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["DefinitionBox4Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox5Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->0.2,
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox5Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["DefinitionBox5Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox6Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox6Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["DefinitionBox6Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[1]],

Cell[StyleData["TopBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontFamily->"Palatino",
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["MiddleBox", "Printout"],
  CellMargins->{{2, 0}, {0, 2}},
  Background->GrayLevel[1]],

Cell[StyleData["MiddleBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 4}},
  FontFamily->"Palatino",
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleSpacedBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left},
  RowMinHeight->1.2}],

Cell[StyleData["MiddleSpacedBox", "Printout"],
  CellMargins->{{2, 0}, {0, 0}},
  Background->GrayLevel[1],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpacedBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 0}},
  FontFamily->"Palatino",
  Background->GrayLevel[1],
  GridBoxOptions->{RowMinHeight->1.8}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BottomBox"],
  CellFrame->{{0.5, 0.5}, {0.5, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left},
  RowMinHeight->1.2}],

Cell[StyleData["BottomBox", "Printout"],
  CellMargins->{{2, 0}, {0, -5}},
  FontSize->10,
  Background->GrayLevel[1],
  GridBoxOptions->{RowMinHeight->2.2}],

Cell[StyleData["BottomBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, -5}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1],
  GridBoxOptions->{RowMinHeight->2.2}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {-2, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopSpanBox", "Printout"],
  CellMargins->{{2, 0}, {-2, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["TopSpanBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-4, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {-3, -8}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left},
  RowMinHeight->1.2}],

Cell[StyleData["MiddleSpanBox", "Printout"],
  CellMargins->{{2, 0}, {-5, 0}},
  FontSize->10,
  Background->GrayLevel[1],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpanBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-7, 0}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1],
  GridBoxOptions->{RowMinHeight->1.8}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{12, Inherited}, {0, 8}},
  CellHorizontalScrolling->True],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{2, Inherited}, {0, 8}}],

Cell[StyleData["Picture", "EnhancedPrintout"],
  CellMargins->{{2, Inherited}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{12, 4}, {0, 2}},
  PageBreakAbove->False,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontSize->7],

Cell[StyleData["Caption", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontFamily->"Futura",
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tables", "Section"],

Cell[CellGroupData[{

Cell[StyleData["SingleRowTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnAlignments->{Left}}],

Cell[StyleData["SingleRowTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["SingleRowTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->{0.34, 0.64},
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["2ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["2ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnEvenTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.49,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["2ColumnEvenTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["2ColumnEvenTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->{0.28, 0.28, 0.43},
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["3ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["3ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["4ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.25,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["4ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["4ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["5ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.2,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["5ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["5ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["6ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.16,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["6ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["6ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["7ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.14,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["7ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["7ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["8ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.12,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["8ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}],

Cell[StyleData["8ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{45, 10}, {7, 7}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{39, 55}, {0, 10}},
  FontSize->10],

Cell[StyleData["NumberedEquation", "EnhancedPrintout"],
  CellMargins->{{39, 55}, {0, 10}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{45, Inherited}, {7, 7}},
  CellHorizontalScrolling->True,
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"]],

Cell[StyleData["DisplayFormula", "EnhancedPrintout"],
  FontFamily->"Palatino"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayMath"],
  CellMargins->{{45, 10}, {7, 7}},
  Evaluatable->False,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input"],

Cell[StyleData["DisplayMath", "Printout"],
  CellMargins->{{39, 0}, {6, 6}},
  FontSize->9],

Cell[StyleData["DisplayMath", "EnhancedPrintout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontFamily->"WRICourier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["EquationNumber"],
  LineSpacing->{1.83, 0}],

Cell[StyleData["EquationNumber", "Printout"],
  LineSpacing->{1.7, 0}],

Cell[StyleData["EquationNumber", "EnhancedPrintout"],
  LineSpacing->{1.7, 0},
  FontFamily->"Palatino"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{12, Inherited}, {7, 7}},
  CellFrameMargins->{{0, 0}, {7, 5}},
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontSize->9.5],

Cell[StyleData["Program", "EnhancedPrintout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontFamily->"WRICourier",
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Contents and Index", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ContentsTitle"],
  CellMargins->{{10, 4}, {0, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->26,
  FontWeight->"Bold"],

Cell[StyleData["ContentsTitle", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->18],

Cell[StyleData["ContentsTitle", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentsSection"],
  CellMargins->{{20, 4}, {3, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["ContentsSection", "Printout"],
  CellMargins->{{12, 0}, {3, 18}},
  PageBreakBelow->False,
  FontSize->11],

Cell[StyleData["ContentsSection", "EnhancedPrintout"],
  CellMargins->{{12, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Contents"],
  CellMargins->{{21, 4}, {0, 8}},
  StyleMenuListing->None],

Cell[StyleData["Contents", "Printout"],
  CellMargins->{{13, 0}, {0, 8}}],

Cell[StyleData["Contents", "EnhancedPrintout"],
  CellMargins->{{13, 0}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Index"],
  CellMargins->{{21, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["Index", "Printout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["Index", "EnhancedPrintout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSubentry"],
  CellMargins->{{36, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["IndexSubentry", "Printout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["IndexSubentry", "EnhancedPrintout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Browser Emulation", "Section"],

Cell[CellGroupData[{

Cell[StyleData["TextNormal"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Text",
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["TextNormal", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BrowserEmulation"],
  CellMargins->{{12, 1}, {7, 24}},
  CellGroupingRules->{"SectionGrouping", 70},
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  GridBoxOptions->{ColumnWidths->0.25,
  ColumnAlignments->{Left},
  GridFrame->True,
  GridFrameMargins->0.5,
  ColumnLines->True}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CategoryDefs"],
  CellMargins->{{300, 10}, {7, 7}},
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  Background->RGBColor[1, 0.8, 0.6],
  GridBoxOptions->{ColumnAlignments->{Left},
  GridFrame->False,
  RowLines->True,
  ColumnLines->True}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category1"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 50},
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Category1", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category2"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{85, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Category2", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category3"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{157, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 70},
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[0.2, 0, 0.4]],

Cell[StyleData["Category3", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category4"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{230, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 80},
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.300008, 0.4]],

Cell[StyleData["Category4", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->8,
  FontWeight->"Bold"],

Cell[StyleData["Header", "Printout"]],

Cell[StyleData["Header", "EnhancedPrintout"],
  FontFamily->"Futura"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontSlant->"Plain"],

Cell[StyleData["Footer", "Printout"]],

Cell[StyleData["Footer", "EnhancedPrintout"],
  FontFamily->"Futura"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->8,
  FontWeight->"Bold"],

Cell[StyleData["PageNumber", "Printout"]],

Cell[StyleData["PageNumber", "EnhancedPrintout"],
  FontFamily->"Futura"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{14, Automatic}, {Automatic, 3}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 62, "Subtitle"],
Cell[1771, 53, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[1989, 61, 35, 0, 50, "Section"],
Cell[2027, 63, 101, 3, 30, "Text"],
Cell[2131, 68, 610, 16, 36, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[2778, 89, 42, 0, 30, "Section"],
Cell[2823, 91, 103, 3, 36, 31, 0, "StyleData", "All", "Working"],
Cell[2929, 96, 106, 3, 36, 35, 0, "StyleData", "All", "AllBrackets"],
Cell[3038, 101, 166, 5, 34, 32, 0, "StyleData", "All", "Printout"],
Cell[3207, 108, 200, 6, 35, 40, 0, "StyleData", "All", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[3444, 119, 38, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[3507, 123, 371, 10, 112, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[3881, 135, 88, 2, 91, 36, 0, "StyleData", "Title", "Printout"],
Cell[3972, 139, 120, 3, 104, 44, 0, "StyleData", "Title", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4129, 147, 314, 8, 58, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[4446, 157, 91, 2, 70, 39, 0, "StyleData", "Subtitle", "Printout"],
Cell[4540, 161, 123, 3, 70, 47, 0, "StyleData", "Subtitle", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4700, 169, 317, 8, 46, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5020, 179, 93, 2, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"],
Cell[5116, 183, 125, 3, 70, 50, 0, "StyleData", "Subsubtitle", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5278, 191, 358, 10, 56, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[5639, 203, 88, 2, 71, 38, 0, "StyleData", "Section", "Printout"],
Cell[5730, 207, 120, 3, 78, 46, 0, "StyleData", "Section", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5887, 215, 323, 9, 44, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[6213, 226, 91, 2, 61, 41, 0, "StyleData", "Subsection", "Printout"],
Cell[6307, 230, 123, 3, 67, 49, 0, "StyleData", "Subsection", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6467, 238, 233, 6, 42, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[6703, 246, 94, 2, 70, 44, 0, "StyleData", "Subsubsection", "Printout"],
Cell[6800, 250, 126, 3, 70, 52, 0, "StyleData", "Subsubsection", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6975, 259, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[7039, 263, 140, 4, 42, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[7182, 269, 108, 3, 39, 35, 0, "StyleData", "Text", "Printout"],
Cell[7293, 274, 142, 4, 40, 43, 0, "StyleData", "Text", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7472, 283, 165, 5, 36, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[7640, 290, 112, 3, 33, 40, 0, "StyleData", "SmallText", "Printout"],
Cell[7755, 295, 146, 4, 34, 48, 0, "StyleData", "SmallText", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7950, 305, 42, 0, 30, "Section"],
Cell[7995, 307, 248, 5, 62, "Text"],

Cell[CellGroupData[{
Cell[8268, 316, 492, 15, 42, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[8763, 333, 111, 3, 36, 36, 0, "StyleData", "Input", "Printout"],
Cell[8877, 338, 119, 3, 36, 44, 0, "StyleData", "Input", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9033, 346, 479, 14, 39, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[9515, 362, 112, 3, 36, 37, 0, "StyleData", "Output", "Printout"],
Cell[9630, 367, 120, 3, 36, 45, 0, "StyleData", "Output", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9787, 375, 549, 16, 38, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[10339, 393, 164, 4, 34, 38, 0, "StyleData", "Message", "Printout"],
Cell[10506, 399, 197, 5, 34, 46, 0, "StyleData", "Message", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10740, 409, 523, 15, 36, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[11266, 426, 135, 3, 34, 36, 0, "StyleData", "Print", "Printout"],
Cell[11404, 431, 168, 4, 34, 44, 0, "StyleData", "Print", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11609, 440, 414, 12, 36, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[12026, 454, 163, 4, 34, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[12192, 460, 196, 5, 34, 47, 0, "StyleData", "Graphics", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12425, 470, 128, 4, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[12556, 476, 130, 4, 32, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[12689, 482, 138, 4, 32, 48, 0, "StyleData", "CellLabel", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12876, 492, 36, 0, 30, "Section"],
Cell[12915, 494, 121, 3, 46, "Text"],
Cell[13039, 499, 92, 3, 36, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[13134, 504, 69, 2, 38, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[13206, 508, 70, 2, 38, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[13279, 512, 115, 4, 36, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[13397, 518, 116, 4, 38, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[13516, 524, 114, 4, 38, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[13633, 530, 116, 4, 38, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[13752, 536, 117, 4, 36, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[13872, 542, 118, 4, 37, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[13993, 548, 116, 4, 37, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[14112, 554, 118, 4, 37, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[14233, 560, 119, 4, 37, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[14355, 566, 120, 4, 38, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[14478, 572, 118, 4, 38, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[14599, 578, 120, 4, 38, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[14744, 586, 138, 5, 35, 23, 0, "StyleData", "SO10", "All",
  StyleMenuListing->None],
Cell[14885, 593, 149, 5, 31, 35, 0, "StyleData", "SO10", "Printout",
  StyleMenuListing->None],
Cell[15037, 600, 154, 5, 34, 43, 0, "StyleData", "SO10", "EnhancedPrintout",
  StyleMenuListing->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15240, 611, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[15304, 615, 215, 6, 42, 30, 0, "StyleData", "MathCaption", "All"],
Cell[15522, 623, 121, 3, 41, 42, 0, "StyleData", "MathCaption", "Printout"],
Cell[15646, 628, 155, 4, 42, 50, 0, "StyleData", "MathCaption", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15838, 637, 256, 8, 41, 29, 0, "StyleData", "Commentary", "All"],
Cell[16097, 647, 125, 3, 39, 41, 0, "StyleData", "Commentary", "Printout"],
Cell[16225, 652, 159, 4, 40, 49, 0, "StyleData", "Commentary", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16421, 661, 177, 5, 32, 31, 0, "StyleData", "ItemizedText", "All",
  CounterIncrements->"ItemizedText"],
Cell[16601, 668, 83, 2, 31, 43, 0, "StyleData", "ItemizedText", "Printout"],
Cell[16687, 672, 117, 3, 32, 51, 0, "StyleData", "ItemizedText", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16841, 680, 149, 4, 32, 35, 0, "StyleData", "ItemizedTextNote", "All",
  CounterIncrements->"Text"],
Cell[16993, 686, 97, 2, 31, 47, 0, "StyleData", "ItemizedTextNote", 
"Printout"],
Cell[17093, 690, 131, 3, 32, 55, 0, "StyleData", "ItemizedTextNote", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17261, 698, 145, 4, 32, 31, 0, "StyleData", "IndentedText", "All",
  CounterIncrements->"Text"],
Cell[17409, 704, 59, 1, 33, 43, 0, "StyleData", "IndentedText", "Printout"],
Cell[17471, 707, 93, 2, 34, 51, 0, "StyleData", "IndentedText", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17613, 715, 46, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[17684, 719, 404, 14, 53, 32, 0, "StyleData", "DefinitionBox", "All",
  StyleMenuListing->None],
Cell[18091, 735, 121, 3, 52, 44, 0, "StyleData", "DefinitionBox", 
"Printout"],
Cell[18215, 740, 155, 4, 53, 52, 0, "StyleData", "DefinitionBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18407, 749, 413, 14, 49, 36, 0, "StyleData", "DefinitionBox3Col", "All",
  StyleMenuListing->None],
Cell[18823, 765, 125, 3, 52, 48, 0, "StyleData", "DefinitionBox3Col", 
"Printout"],
Cell[18951, 770, 159, 4, 53, 56, 0, "StyleData", "DefinitionBox3Col", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19147, 779, 422, 14, 49, 36, 0, "StyleData", "DefinitionBox4Col", "All",
  StyleMenuListing->None],
Cell[19572, 795, 125, 3, 52, 48, 0, "StyleData", "DefinitionBox4Col", 
"Printout"],
Cell[19700, 800, 159, 4, 53, 56, 0, "StyleData", "DefinitionBox4Col", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19896, 809, 401, 14, 49, 36, 0, "StyleData", "DefinitionBox5Col", "All",
  StyleMenuListing->None],
Cell[20300, 825, 125, 3, 52, 48, 0, "StyleData", "DefinitionBox5Col", 
"Printout"],
Cell[20428, 830, 159, 4, 53, 56, 0, "StyleData", "DefinitionBox5Col", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20624, 839, 434, 14, 49, 36, 0, "StyleData", "DefinitionBox6Col", "All",
  StyleMenuListing->None],
Cell[21061, 855, 125, 3, 52, 48, 0, "StyleData", "DefinitionBox6Col", 
"Printout"],
Cell[21189, 860, 159, 4, 53, 56, 0, "StyleData", "DefinitionBox6Col", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21385, 869, 417, 14, 48, 25, 0, "StyleData", "TopBox", "All",
  StyleMenuListing->None],
Cell[21805, 885, 98, 2, 44, 37, 0, "StyleData", "TopBox", "Printout"],
Cell[21906, 889, 132, 3, 46, 45, 0, "StyleData", "TopBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22075, 897, 444, 15, 48, 28, 0, "StyleData", "MiddleBox", "All",
  StyleMenuListing->None],
Cell[22522, 914, 101, 2, 30, 40, 0, "StyleData", "MiddleBox", "Printout"],
Cell[22626, 918, 135, 3, 34, 48, 0, "StyleData", "MiddleBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22798, 926, 471, 16, 48, 34, 0, "StyleData", "MiddleSpacedBox", "All",
  StyleMenuListing->None],
Cell[23272, 944, 146, 3, 28, 46, 0, "StyleData", "MiddleSpacedBox", 
"Printout"],
Cell[23421, 949, 180, 4, 30, 54, 0, "StyleData", "MiddleSpacedBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23638, 958, 467, 16, 48, 28, 0, "StyleData", "BottomBox", "All",
  StyleMenuListing->None],
Cell[24108, 976, 157, 4, 30, 40, 0, "StyleData", "BottomBox", "Printout"],
Cell[24268, 982, 191, 5, 31, 48, 0, "StyleData", "BottomBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24496, 992, 421, 14, 46, 29, 0, "StyleData", "TopSpanBox", "All",
  StyleMenuListing->None],
Cell[24920, 1008, 119, 3, 41, 41, 0, "StyleData", "TopSpanBox", "Printout"],
Cell[25042, 1013, 153, 4, 40, 49, 0, "StyleData", "TopSpanBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25232, 1022, 469, 16, 45, 32, 0, "StyleData", "MiddleSpanBox", "All",
  StyleMenuListing->None],
Cell[25704, 1040, 161, 4, 22, 44, 0, "StyleData", "MiddleSpanBox", 
"Printout"],
Cell[25868, 1046, 195, 5, 21, 52, 0, "StyleData", "MiddleSpanBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26100, 1056, 101, 2, 32, 26, 0, "StyleData", "Picture", "All"],
Cell[26204, 1060, 79, 1, 36, 38, 0, "StyleData", "Picture", "Printout"],
Cell[26286, 1063, 87, 1, 36, 46, 0, "StyleData", "Picture", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26410, 1069, 127, 4, 30, 26, 0, "StyleData", "Caption", "All"],
Cell[26540, 1075, 86, 2, 29, 38, 0, "StyleData", "Caption", "Printout"],
Cell[26629, 1079, 118, 3, 32, 46, 0, "StyleData", "Caption", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26796, 1088, 25, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[26846, 1092, 299, 10, 36, 33, 0, "StyleData", "SingleRowTable", "All",
  StyleMenuListing->None],
Cell[27148, 1104, 78, 1, 36, 45, 0, "StyleData", "SingleRowTable", 
"Printout"],
Cell[27229, 1107, 86, 1, 36, 53, 0, "StyleData", "SingleRowTable", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27352, 1113, 335, 11, 32, 31, 0, "StyleData", "2ColumnTable", "All",
  StyleMenuListing->None],
Cell[27690, 1126, 76, 1, 36, 43, 0, "StyleData", "2ColumnTable", "Printout"],
Cell[27769, 1129, 84, 1, 36, 51, 0, "StyleData", "2ColumnTable", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27890, 1135, 331, 11, 32, 35, 0, "StyleData", "2ColumnEvenTable", "All",
  StyleMenuListing->None],
Cell[28224, 1148, 80, 1, 36, 47, 0, "StyleData", "2ColumnEvenTable", 
"Printout"],
Cell[28307, 1151, 88, 1, 36, 55, 0, "StyleData", "2ColumnEvenTable", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28432, 1157, 341, 11, 32, 31, 0, "StyleData", "3ColumnTable", "All",
  StyleMenuListing->None],
Cell[28776, 1170, 76, 1, 36, 43, 0, "StyleData", "3ColumnTable", "Printout"],
Cell[28855, 1173, 84, 1, 36, 51, 0, "StyleData", "3ColumnTable", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28976, 1179, 327, 11, 32, 31, 0, "StyleData", "4ColumnTable", "All",
  StyleMenuListing->None],
Cell[29306, 1192, 76, 1, 36, 43, 0, "StyleData", "4ColumnTable", "Printout"],
Cell[29385, 1195, 84, 1, 36, 51, 0, "StyleData", "4ColumnTable", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29506, 1201, 326, 11, 32, 31, 0, "StyleData", "5ColumnTable", "All",
  StyleMenuListing->None],
Cell[29835, 1214, 76, 1, 36, 43, 0, "StyleData", "5ColumnTable", "Printout"],
Cell[29914, 1217, 84, 1, 36, 51, 0, "StyleData", "5ColumnTable", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30035, 1223, 327, 11, 32, 31, 0, "StyleData", "6ColumnTable", "All",
  StyleMenuListing->None],
Cell[30365, 1236, 76, 1, 36, 43, 0, "StyleData", "6ColumnTable", "Printout"],
Cell[30444, 1239, 84, 1, 36, 51, 0, "StyleData", "6ColumnTable", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30565, 1245, 327, 11, 32, 31, 0, "StyleData", "7ColumnTable", "All",
  StyleMenuListing->None],
Cell[30895, 1258, 76, 1, 36, 43, 0, "StyleData", "7ColumnTable", "Printout"],
Cell[30974, 1261, 84, 1, 36, 51, 0, "StyleData", "7ColumnTable", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31095, 1267, 327, 11, 32, 31, 0, "StyleData", "8ColumnTable", "All",
  StyleMenuListing->None],
Cell[31425, 1280, 76, 1, 36, 43, 0, "StyleData", "8ColumnTable", "Printout"],
Cell[31504, 1283, 84, 1, 36, 51, 0, "StyleData", "8ColumnTable", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[31637, 1290, 49, 0, 30, "Section"],
Cell[31689, 1292, 225, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[31939, 1300, 318, 7, 42, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[32260, 1309, 99, 2, 37, 47, 0, "StyleData", "NumberedEquation", 
"Printout"],
Cell[32362, 1313, 133, 3, 38, 55, 0, "StyleData", "NumberedEquation", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32544, 1322, 43, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[32612, 1326, 211, 5, 42, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[32826, 1333, 45, 0, 42, 45, 0, "StyleData", "DisplayFormula", 
"Printout"],
Cell[32874, 1335, 79, 1, 44, 53, 0, "StyleData", "DisplayFormula", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32990, 1341, 389, 12, 39, 30, 0, "StyleData", "DisplayMath", "All",
  CounterIncrements->"Input"],
Cell[33382, 1355, 91, 2, 38, 42, 0, "StyleData", "DisplayMath", "Printout"],
Cell[33476, 1359, 127, 3, 37, 50, 0, "StyleData", "DisplayMath", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33640, 1367, 59, 1, 36, 33, 0, "StyleData", "EquationNumber", "All"],
Cell[33702, 1370, 70, 1, 36, 45, 0, "StyleData", "EquationNumber", 
"Printout"],
Cell[33775, 1373, 104, 2, 38, 53, 0, "StyleData", "EquationNumber", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33916, 1380, 166, 4, 52, 26, 0, "StyleData", "Program", "All"],
Cell[34085, 1386, 98, 2, 51, 38, 0, "StyleData", "Program", "Printout"],
Cell[34186, 1390, 134, 3, 52, 46, 0, "StyleData", "Program", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[34369, 1399, 37, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[34431, 1403, 158, 5, 60, 32, 0, "StyleData", "ContentsTitle", "All",
  StyleMenuListing->None],
Cell[34592, 1410, 119, 3, 70, 44, 0, "StyleData", "ContentsTitle", 
"Printout"],
Cell[34714, 1415, 151, 4, 70, 52, 0, "StyleData", "ContentsTitle", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34902, 1424, 160, 5, 37, 34, 0, "StyleData", "ContentsSection", "All",
  StyleMenuListing->None],
Cell[35065, 1431, 122, 3, 48, 46, 0, "StyleData", "ContentsSection", 
"Printout"],
Cell[35190, 1436, 154, 4, 53, 54, 0, "StyleData", "ContentsSection", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[35381, 1445, 87, 2, 32, 27, 0, "StyleData", "Contents", "All",
  StyleMenuListing->None],
Cell[35471, 1449, 73, 1, 70, 39, 0, "StyleData", "Contents", "Printout"],
Cell[35547, 1452, 123, 3, 70, 47, 0, "StyleData", "Contents", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[35707, 1460, 108, 3, 32, 24, 0, "StyleData", "Index", "All",
  StyleMenuListing->None],
Cell[35818, 1465, 86, 2, 70, 36, 0, "StyleData", "Index", "Printout"],
Cell[35907, 1469, 120, 3, 70, 44, 0, "StyleData", "Index", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36064, 1477, 116, 3, 32, 32, 0, "StyleData", "IndexSubentry", "All",
  StyleMenuListing->None],
Cell[36183, 1482, 94, 2, 70, 44, 0, "StyleData", "IndexSubentry", 
"Printout"],
Cell[36280, 1486, 128, 3, 70, 52, 0, "StyleData", "IndexSubentry", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[36457, 1495, 36, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[36518, 1499, 155, 5, 42, 29, 0, "StyleData", "TextNormal", "All",
  CounterIncrements->"Text"],
Cell[36676, 1506, 74, 1, 40, 41, 0, "StyleData", "TextNormal", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36787, 1512, 299, 9, 40, 35, 0, "StyleData", "BrowserEmulation", "All"],
Cell[37089, 1523, 68, 1, 40, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37194, 1529, 259, 8, 56, 31, 0, "StyleData", "CategoryDefs", "All"],
Cell[37456, 1539, 68, 1, 40, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37561, 1545, 205, 6, 43, 28, 0, "StyleData", "Category1", "All"],
Cell[37769, 1553, 73, 1, 70, 40, 0, "StyleData", "Category1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37879, 1559, 244, 7, 43, 28, 0, "StyleData", "Category2", "All"],
Cell[38126, 1568, 73, 1, 70, 40, 0, "StyleData", "Category2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38236, 1574, 242, 7, 41, 28, 0, "StyleData", "Category3", "All"],
Cell[38481, 1583, 73, 1, 70, 40, 0, "StyleData", "Category3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38591, 1589, 231, 6, 41, 28, 0, "StyleData", "Category4", "All"],
Cell[38825, 1597, 73, 1, 70, 40, 0, "StyleData", "Category4", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[38947, 1604, 49, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[39021, 1608, 148, 5, 29, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[39172, 1615, 37, 0, 29, 37, 0, "StyleData", "Header", "Printout"],
Cell[39212, 1617, 69, 1, 29, 45, 0, "StyleData", "Header", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39318, 1623, 148, 5, 27, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[39469, 1630, 37, 0, 27, 37, 0, "StyleData", "Footer", "Printout"],
Cell[39509, 1632, 69, 1, 27, 45, 0, "StyleData", "Footer", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39615, 1638, 152, 5, 32, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None],
Cell[39770, 1645, 41, 0, 29, 41, 0, "StyleData", "PageNumber", "Printout"],
Cell[39814, 1647, 73, 1, 29, 49, 0, "StyleData", "PageNumber", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[39936, 1654, 35, 0, 30, "Section"],
Cell[39974, 1656, 184, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[40183, 1664, 302, 8, 36, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[40488, 1674, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"],
Cell[40614, 1679, 157, 4, 70, 48, 0, "StyleData", "Hyperlink", 
"EnhancedPrintout"]
}, Closed]],
Cell[40786, 1686, 104, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[40915, 1693, 316, 8, 36, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[41234, 1703, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", 
"Printout"],
Cell[41363, 1708, 160, 4, 70, 51, 0, "StyleData", "MainBookLink", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[41560, 1717, 337, 9, 36, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[41900, 1728, 124, 3, 35, 41, 0, "StyleData", "AddOnsLink", "Printout"],
Cell[42027, 1733, 160, 4, 35, 49, 0, "StyleData", "AddOnsLink", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[42224, 1742, 341, 9, 36, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42568, 1753, 126, 3, 35, 43, 0, "StyleData", "RefGuideLink", 
"Printout"],
Cell[42697, 1758, 162, 4, 35, 51, 0, "StyleData", "RefGuideLink", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[42896, 1767, 328, 8, 36, 37, 0, "StyleData", "GettingStartedLink", 
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[43227, 1777, 132, 3, 35, 49, 0, "StyleData", "GettingStartedLink", 
"Printout"],
Cell[43362, 1782, 166, 4, 36, 57, 0, "StyleData", "GettingStartedLink", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[43565, 1791, 332, 8, 36, 39, 0, "StyleData", "OtherInformationLink", 
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[43900, 1801, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", 
"Printout"],
Cell[44037, 1806, 168, 4, 70, 59, 0, "StyleData", "OtherInformationLink", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

